==> nextcloud-app-calendar-1%3A2.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/lb.js <==
OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Prost!",
    "Calendar" : "Kalenner",
    "Today" : "Haut",
    "Day" : "Dag",
    "Week" : "Woch",
    "Month" : "Mount",
    "Download" : "Eroflueden",
    "Delete" : "Läschen",
    "Share link" : "Link deelen",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "can edit" : "kann änneren",
    "New calendar" : "Neie Kalenner",
    "Cancel" : "Ofbriechen",
    "Automatic" : "Automatesch",
    "Actions" : "Aktiounen",
    "Email" : "Email",
    "Unknown" : "Onbekannt",
    "never" : "Ni",
    "after" : "No",
    "Repeat" : "Widderhuelen",
    "Monday" : "Méindeg",
    "More" : "Méi",
    "Save" : "Späicheren",
    "Update" : "Update",
    "Personal" : "Perséinlech",
    "Details" : "Detailer",
    "Attendees" : "Participanten",
    "Reminders" : "Erennërungen",
    "Activity" : "Aktivitéit",
    "Close" : "Zoumaachen",
    "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
    "Location" : "Uert",
    "Description" : "Beschreiwung",
    "Cancelled" : "Ofgebrach",
    "Mail" : "Mail",
    "Play" : "Ofspillen",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A4.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/lb.js <==
OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Prost!",
    "Calendar" : "Kalenner",
    "New event" : "Neit Evenement",
    "Today" : "Haut",
    "Day" : "Dag",
    "Week" : "Woch",
    "Month" : "Mount",
    "Copy link" : "Link kopéieren",
    "Edit" : "Änneren",
    "Delete" : "Läschen",
    "Export" : "Exportéieren",
    "Share link" : "Link deelen",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "can edit" : "kann änneren",
    "New calendar" : "Neie Kalenner",
    "Name" : "Numm",
    "Deleted" : "Geläscht",
    "Restore" : "Zrécksetzen",
    "Delete permanently" : "Permanent läschen",
    "Cancel" : "Ofbriechen",
    "Automatic" : "Automatesch",
    "Actions" : "Aktiounen",
    "Location" : "Uert",
    "Description" : "Beschreiwung",
    "to" : "bis",
    "Add" : "Derbäimaachen",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sunday" : "Sonndeg",
    "Save" : "Späicheren",
    "Update" : "Update",
    "Your email address" : "Deng Email Adress",
    "Email" : "Email",
    "Unknown" : "Onbekannt",
    "Repeat" : "Widderhuelen",
    "never" : "Ni",
    "after" : "No",
    "More" : "Méi",
    "Global" : "Global",
    "Personal" : "Perséinlech",
    "Details" : "Detailer",
    "Attendees" : "Participanten",
    "Close" : "Zoumaachen",
    "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "Next" : "Weider",
    "Other" : "Aner",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
    "Mail" : "Mail",
    "Birthday" : "Gebuertsdag"
},
"nplurals=2; plural=(n != 1);");
